@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION='1.0';
+$VERSION='1.01';
 require Net::SMTPS;
 require Net::SMTP;
 use MIME::Base64;
@@ -286,7 +286,7 @@ sub send
         print "With Attachments\n" if $verbose;
         $self->{sender}->datasend("MIME-Version: 1.0\n");
         if ((defined $properties{'-disposition'}) and ('inline' eq lc($properties{'-disposition'}))) {
-            $self->{sender}->datasend("Content-Type: multipart/related; BOUNDARY=\"$boundary\"\n");
+           $self->{sender}->datasend("Content-Type: multipart/related; BOUNDARY=\"$boundary\"\n");
         }
         else {
            $self->{sender}->datasend("Content-Type: multipart/mixed; BOUNDARY=\"$boundary\"\n");
@@ -347,7 +347,7 @@ sub send
            $self->{sender}->datasend($_) foreach @groups;
            close $file;
 
-           $self->{sender}->datasend("--$boundary\n");
+           #$self->{sender}->datasend("--$boundary\n"); # avoid dummy attachment
          }
          $self->{sender}->datasend("\n--$boundary--\n"); # send endboundary end message
       }
@@ -414,7 +414,7 @@ sub send
            $self->{sender}->datasend($_) foreach @groups;
            close $file;
 
-           $self->{sender}->datasend("--$boundary\n");
+           #$self->{sender}->datasend("--$boundary\n"); # to avoid noname.txt dummy attachment
         }
         $self->{sender}->datasend("\n--$boundary--\n"); # send endboundary end message
       }
